void run3()
{
  // for running with root only
  gSystem->Load("libTree.so");
  gSystem->Load("libGeom.so");
  gSystem->Load("libVMC.so");
  gSystem->Load("libSTEERBase.so");
  gSystem->Load("libESD.so");
  gSystem->Load("libAOD.so"); 

  // load analysis framework
  gSystem->Load("libANALYSIS");
  gSystem->Load("libANALYSISalice");

  gROOT->LoadMacro("$ALICE_ROOT/PWG0/CreateESDChain.C");
  TChain* chain = CreateESDChain("files.txt", 2);

  // for includes use either global setting in $HOME/.rootrc
  // ACLiC.IncludePaths: -I$(ALICE_ROOT)/include
  // or in each macro
  gSystem->AddIncludePath("-I$ALICE_ROOT/include");

  // Create the analysis manager
  AliAnalysisManager *mgr = new AliAnalysisManager("testAnalysis");

  AliVEventHandler* esdH = new AliESDInputHandler;
  mgr->SetInputEventHandler(esdH);

  // Create tasks
  gROOT->LoadMacro("AliAnalysisTaskPtMC.cxx+g");
  gROOT->LoadMacro("AliAnalysisTaskPt.cxx+g");

  AliAnalysisTask *task1 = new AliAnalysisTaskPtMC("TaskPtMC");
  // Enable MC event handler

  AliMCEventHandler* handler = new AliMCEventHandler;
  handler->SetReadTR(kFALSE);
  mgr->SetMCtruthEventHandler(handler);
  AliAnalysisTask *task2  = new AliAnalysisTaskPt("TaskPt");

  // Add tasks
  mgr->AddTask(task1);
  mgr->AddTask(task2);

  // Create containers for input/output
  AliAnalysisDataContainer *cinput = mgr->GetCommonInputContainer();
  AliAnalysisDataContainer *coutput1 = mgr->CreateContainer("chist1", TH1::Class(),    AliAnalysisManager::kOutputContainer, "Pt.ESD.1.root");
  AliAnalysisDataContainer *coutput2 = mgr->CreateContainer("chist2", TH1::Class(),    AliAnalysisManager::kOutputContainer, "Pt.MC.1.root");

  // Connect input/output
  mgr->ConnectInput(task1, 0, cinput);
  mgr->ConnectInput(task2, 0, cinput);
  mgr->ConnectOutput(task1, 0, coutput1);
  mgr->ConnectOutput(task2, 0, coutput2);

  // Enable debug printouts
  mgr->SetDebugLevel(2);

  if (!mgr->InitAnalysis())
    return;

  mgr->PrintStatus();

  mgr->StartAnalysis("local", chain);
}
