#ifndef AliAnalysisTaskPtCF_h
#define AliAnalysisTaskPtCF_h

// example of an analysis task creating a p_t spectrum
// Authors: Panos Cristakoglou, Jan Fiete Grosse-Oetringhaus, Christian Klein-Boesing
// extended with correction framework related operations
// Authors: Renaud Vernet, Annalisa Mastroserio, Ingrid Kraus

class TH1F;
class TList;
class AliCFTrackKineCuts;
class AliCFTrackQualityCuts;
class AliCFContainer;

#include "AliAnalysisTaskSE.h"

class AliAnalysisTaskPtCF : public AliAnalysisTaskSE {
 public:
  AliAnalysisTaskPtCF();
//   AliAnalysisTaskPtCF(const char *name = "AliAnalysisTaskPtCF");
  AliAnalysisTaskPtCF(const char *name);

  AliAnalysisTaskPtCF& operator= (const AliAnalysisTaskPtCF& c);
  AliAnalysisTaskPtCF(const AliAnalysisTaskPtCF& c);
  virtual ~AliAnalysisTaskPtCF();
  
  virtual void   UserCreateOutputObjects();
  virtual void   UserExec(Option_t *option);
  virtual void   Terminate(Option_t *);

  // correction framework related functions
  void SetKineCutsMC(AliCFTrackKineCuts* kinecutsMC)		{fKineCutsMC  = kinecutsMC;}
  void SetKineCutsRec(AliCFTrackKineCuts* kinecutsRec)		{fKineCutsRec = kinecutsRec;}
  void SetQualityCuts(AliCFTrackQualityCuts* qualitycuts)	{fQualityCuts = qualitycuts;}
  void SetContainer(AliCFContainer* aliCFContainer)		{fAliCFContainer = aliCFContainer;}
  void SetQAList(TList* qalist)					{fQAList = qalist;}
  
 private:
  TH1F        *fHistPtMC;  //Pt spectrum - generated particles
  TH1F        *fHistPtRec; //Pt spectrum - reconstructed tracks

  AliCFTrackKineCuts    *fKineCutsMC;	// cut on particle's kinematic quantities
  AliCFTrackKineCuts    *fKineCutsRec;	// cut on track's kinematic quantities
  AliCFTrackQualityCuts *fQualityCuts;	// cut on track quality
  TList                 *fQAList;      	// list of QA histograms
  AliCFContainer        *fAliCFContainer;  // container for efficiency calculation
  
//   AliAnalysisTaskPtCF(const AliAnalysisTaskPtCF&); // not implemented
//   AliAnalysisTaskPtCF& operator=(const AliAnalysisTaskPtCF&); // not implemented
  
  ClassDef(AliAnalysisTaskPtCF, 1); // example of analysis
};

#endif
