void run6()
{
  // load analysis framework
  gSystem->Load("libANALYSIS");
  gSystem->Load("libANALYSISalice");
  gSystem->Load("libCORRFW");

  gROOT->LoadMacro("$ALICE_ROOT/PWG0/CreateESDChain.C");
  TChain* chain = CreateESDChain("files.txt", 2);

  // for includes use either global setting in $HOME/.rootrc
  // ACLiC.IncludePaths: -I$(ALICE_ROOT)/include
  // or in each macro
  gSystem->AddIncludePath("-I$ALICE_ROOT/include");

  // Create the analysis manager
  AliAnalysisManager *mgr = new AliAnalysisManager("testAnalysis");

  // Enable MC event handler
  AliMCEventHandler* handler = new AliMCEventHandler;
  handler->SetReadTR(kFALSE);
  mgr->SetMCtruthEventHandler(handler);

  // Enable event handler
  AliVEventHandler* esdH = new AliESDInputHandler();
  mgr->SetInputEventHandler(esdH);


  // create the cuts

  // generator level kinematic cuts
  // these cuts shall select the particles of interest.
  // Their efficiency shall be studied lateron.
  // Here we will calculate the efficiency of charged tracks around midrapidity.
  AliCFTrackKineCuts *kineCutsMC = new AliCFTrackKineCuts("kineCutsMC","kinematic cuts MC");
  //  kineCutsMC->SetQAOn(kTRUE);
  kineCutsMC->SetEtaRange(-1.,1.);
  kineCutsMC->SetRequireIsCharged(kTRUE);

  // cuts on reconstructed tracks
  // apply the same cuts as for MC particles
  // add more cuts if desired
  AliCFTrackKineCuts *kineCutsRec = new AliCFTrackKineCuts("kineCutsRec","kinematic cuts rec");
  //  kineCutsRec->SetQAOn(kTRUE);
  kineCutsRec->SetEtaRange(-1.,1.);
  kineCutsRec->SetRequireIsCharged(kTRUE);
  kineCutsRec->SetPhiRange(0.,5.);
  // apply also other kind of cuts
  AliCFTrackQualityCuts *qualityCuts = new AliCFTrackQualityCuts("qualityCuts"," quality cuts");
  //  qualityCuts->SetQAOn(kTRUE);
  qualityCuts->SetMinNClusterTPC(50);
//   qualityCuts->SetRequireTPCRefit(kTRUE);

  // create the list for QA histograms
  // the cuts are accompanied by histograms that display relevant quanitities.
  // The histograms are filled before and after cuts are applied.
  TList* qaList = new TList();
  // add the histograms of cut classes to this list
  // so only the list (but not the histograms) need to be passed
  //  kineCutsMC->SetQAOn(kTRUE);
  //  kineCutsRec->SetQAOn(kTRUE);
  //  qualityCuts->SetQAOn(kTRUE);
  kineCutsMC->Init();
  kineCutsRec->Init();
  qualityCuts->Init();
  kineCutsMC->SetQAOn(qaList);
  kineCutsRec->SetQAOn(qaList);
  qualityCuts->SetQAOn(qaList);



  // create the container for the efficiency calculation
  // configure it:
  // set number sensitive variables: eff = eff(pt,eta)
  const Int_t nvar = 2;
  // set binning: 6 bins in pt, 4 bins in eta
  Int_t nbin[nvar] = {6,4};
  // set number of steps: here container is filled twice
  // (1) with MC information
  // (2) with reconstructed tracks after cuts were applied
  Int_t nstep = 2;
  // set bin limits
  Double_t limitsPt[7]  = {0.,0.5,1.,1.5,2.,2.5,3.};
  Double_t limitsEta[5] = {-1.,-0.5,0.,0.5,1.};
  // create container
  AliCFContainer *aliCFContainer = new AliCFContainer("aliCFContainer","container for efficiency calculation",nstep,nvar,nbin);
  aliCFContainer -> SetBinLimits(0, limitsPt);
  aliCFContainer -> SetBinLimits(1, limitsEta);



  // Create task
  gROOT->LoadMacro("AliAnalysisTaskPtCF.cxx+g");
//   AliAnalysisTask *task = new AliAnalysisTaskPtCF("TaskPtCF");
  AliAnalysisTaskPtCF *task = new AliAnalysisTaskPtCF("TaskPtCF");
  // pass the correction framework objects to the task
  task->SetKineCutsMC(kineCutsMC);
  task->SetKineCutsRec(kineCutsRec);
  task->SetQualityCuts(qualityCuts);
  task->SetContainer(aliCFContainer);
  task->SetQAList(qaList);

  // Add task
  mgr->AddTask(task);

  // Create containers for input/output
  AliAnalysisDataContainer *cinput = mgr->GetCommonInputContainer();

//  AliAnalysisDataContainer *coutput0 = mgr->CreateContainer("aod", TTree::Class(),    AliAnalysisManager::kOutputContainer, "default");

  AliAnalysisDataContainer *coutput1 = mgr->CreateContainer("chist1", TH1::Class(),    AliAnalysisManager::kOutputContainer, "PtCF1.root");

  AliAnalysisDataContainer *coutput2 = mgr->CreateContainer("chist2", TH1::Class(),    AliAnalysisManager::kOutputContainer, "PtCF2.root");

  // output Correction Framework Container (for acceptance & efficiency calculations)
  AliAnalysisDataContainer *coutput3 = mgr->CreateContainer("ccontainer0", AliCFContainer::Class(),AliAnalysisManager::kOutputContainer,"PtCF3.root");

  // output QA histograms 
  AliAnalysisDataContainer *coutput4 = mgr->CreateContainer("clist0", TList::Class(),AliAnalysisManager::kOutputContainer,"PtCF4.root");

  // Connect input/output
  mgr->ConnectInput(task,  0, cinput);
//  mgr->ConnectOutput(task, 0, coutput0);
  mgr->ConnectOutput(task, 1, coutput1);
  mgr->ConnectOutput(task, 2, coutput2);
  mgr->ConnectOutput(task, 3, coutput3);
  mgr->ConnectOutput(task, 4, coutput4);


  // Enable debug printouts
  mgr->SetDebugLevel(2);

  if (!mgr->InitAnalysis())
    return;

  mgr->PrintStatus();

  mgr->StartAnalysis("local", chain);
}
